| Score | Dummy (prior)
--- | --- | ---
AUC | 0.779 | 0.500
True Positive Rate | 0.339 | 0.000
True Negative Rate | 0.936 | 1.000
False Positive Rate | 0.064 | 0.000
False Negative Rate | 0.661 | 1.000
Positive Predictive Value | 0.690 | 0.000
Negative Predictive Value | 0.772 | 0.705
F1 Score | 0.455 | 0.000
Precision/Recall AUC | 0.589 | 0.295
Accuracy | 0.760 | 0.705
Error Rate | 0.240 | 0.295
% Positive | 0.295 | 0.295
Total Observations | 200 | 200